/**
 * @author ALEXAN ANDRIEUX
 */
(function($){
	
	function bind(fn, ctx) {
		if (typeof fn.bind === "function") {
			return fn.bind(ctx);
		} else {
			return function() {
				fn.apply(ctx, arguments);
			};
		}
	}

	var browserPrefix = "";
	if ($.layout.browser.mozilla) {
		browserPrefix = "-moz-";
	} else if ($.layout.browser.webkit) {
		browserPrefix = "-webkit-";
	} else if ($.layout.browser.opera) {
		browserPrefix = "-o-";
	} else if ($.layout.browser.msie) {
		browserPrefix = "-ms-";
	}
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////																											  	   ////
	////	Constructor for VizStyle object. VizStyle give the possibilities to set the global style of the graph:		   ////
	////	- graph background color																					   ////
	////	- selection box style (fill, border) : core																	   ////
	////	- nodes style  (fill, border, label) :node																	   ////	
	////	- edges style (fil, border, label)	 : edges																   ////
	////																												   ////
	////	Function call with $(selector).vizstyle(startStyle) with sartStyle is the type of vizStyle (core, node, edge)  ////
	////									  																		  	   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function VizStyle($el){
		
		this.$el = $el;
		this.coreHtml = bind(this.coreHtml, this);
		this.nodesHtml = bind(this.nodesHtml, this);
		this.edgesHtml = bind(this.edgesHtml, this);
	};
	
	VizStyle.prototype = {
		
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////																											  	   ////
	////	Append html code for subtab core																			   ////
	////									  																		  	   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	coreHtml : function(){
		this.$el.empty();
		this.$el.append(
				'<div id="vizstyle_Global" style="">\
					<h2>Background</h2>\
						<div class="property background core" property="core_backgroundColor" type="color">\
							<label class="style">Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
					<h2>Selection Box</h2>\
						<div class="property selectionBox core" property="core_selectionBoxColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text"readonly>\
						</div>\
						<div class="property selectionBox core" property="core_selectionBoxOpacity" type="per_cent_number">\
							<label class="style"> Opacity (%) <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text">\
						</div>\
						<div class="property selectionBox core" property="core_selectionBoxBorderColor" type="color">\
							<label class="style"> Border color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
						</div>\
						<div class="property selectionBox core" property="core_selectionBoxBorderWidth" type="number">\
							<label class="style"> Border width <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text">\
						</div>\
					<h2>Behavior Graph</h2>\
						<div class="property behaviourGraph core" property="core_bubbleBoxCenter" type="focus_checkbox">\
							<label class="style">Center focus on node<span class="ui-validation-error-message"></span></label>\
							<input id=focus_node type="checkbox" />\
						</div>\
					</div>'
		);
		
		//add event set color properties
	    setColors(this.$el);
	
		//add event set numbers properties
		setNumber(this.$el);
	
		//add event set per cent number properties
		setRate(this.$el);
	
	
	
		$("#focus_node").click( function() {   
							$(this).checked();
		});
	},
	
	 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	 ////																											  		////
	 ////	Append html code for subtab node																				////
	 ////   TODO optimisation  liste déroulante : récupérer valeur dans cytoscape.js										////
	 ////	TODO: changer les id																					        ////
	 ////									  																		  		////
	 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	nodesHtml : function () { 
		this.$el.empty(); 
		this.$el.append(
			   '<div id="vizstyle_Nodes" style="">\
			   		<form>\
							<label class="type" for="allNodes">All Nodes</label>\
							<input type="radio" name="typeof_nodes" id="allNodes" value="allNodes">\
							<label class="type" for="root">Root</label>\
							<input type="radio" name="typeof_nodes" id="root" value="root">\
							<label class="type" for="children">Children</label>\
							<input type="radio" name="typeof_nodes" id="children" value="children">\
					</form>\
					<h2>Border</h2>\
						<div class="property border nodes" property="nodes_borderWidth" type="number">\
							<label class="style"> Width <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
						<div class="property border nodes" property="nodes_borderColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
						<div class="property border nodes" property="nodes_borderOpacity" type="per_cent_number">\
							<label class="style"> Opacity <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
					<h2>Fill</h2>\
						<div class="property fill nodes" property="nodes_width" type="number">\
							<label class="style"> Width <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text">\
						</div>\
						<div class="property fill nodes" property="nodes_height" type="number">\
							<label class="style"> Height <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
						</div>\
						<div class="property fill nodes" property="nodes_backgroundColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
						<div class="property fill nodes" property="nodes_backgroundOpacity" type="per_cent_number">\
							<label class="style"> Opacity <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" >\
				       		</div>\
						<div class="property fill nodes" property="nodes_shape" type="node_shape">\
							<label class="style"> Shape <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
					<h2>Label</h2>\
						<div class="property label nodes" property="nodes_labelValign" type="string_selection">\
							<label class="style"> Vertical alignement <span class="ui-validation-error-message"></span></label>\
							<select  class="valign" type="text" >\
								<option value=1 >top</option>\
								<option value=2 >center</option>\
								<option value=3 >bottom</option>\
							</select>\
						</div>\
						<div class="property label nodes" property="nodes_labelHalign" type="string_selection">\
							<label class="style"> Horizontal aligment <span class="ui-validation-error-message"></span></label>\
							<select  class="halign" type="text" ">\
								<option value=1 >right</option>\
								<option value=2 >center</option>\
								<option value=3 >left</option>\
							</select>\
						</div>\
						<div class="property label nodes" property="nodes_labelColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
						<div class="property label nodes" property="nodes_labelWeight" type="string_selection">\
							<label class="style"> Weight <span class="ui-validation-error-message"></span></label>\
							<select  class="weight" type="text" ">\
								<option value=1 >normal</option>\
								<option value=2 >bold</option>\
								<option value=3 >bolder</option>\
								<option value=4 >lighter</option>\
							</select>\
						</div>\
						<div class="property label nodes" property="nodes_labelSize" type="number">\
							<label class="style"> Size <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
					</div>'
		);
		
		
		this.$el.find("#allNodes").prop("checked", "checked");
		
		var $el = this.$el;
		//change values of vizstyle input with css values of root nodes
		$("#root").click(function(){
		 	inputUpdate($el);    
		});
		//change values of vizstyle input with css values of root nodes
		$("#allNodes").click(function(){
		 	inputUpdate($el);    
		});
		$("#children").click(function(){
		 	inputUpdate($el);  
		});
		
		//add event set color properties
	    setColors(this.$el);
	
	    //add event set node shape properties 
	    setNodeShape(this.$el);
	
		//add event set border shape properties
		setLineShape(this.$el);
	
		// add event set numbers properties
		setNumber(this.$el);
	
		// add event set per cent number properties
		setRate(this.$el);
	
		// add event set string selection
		setString (this.$el);
	},
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////																											  		////
	////	Append html code for subtab core																				////
	////   TODO optimisation  liste déroulante : récupérer valeur dans cytoscape.js										////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	edgesHtml : function () {
		this.$el.empty();  
		this.$el.append(
			   '<div id="vizstyle_Edges" style="">\
					<h2>Line</h2>\
						<div class="property line edges" property="edges_width" type="number">\
							<label class="style"> Width <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
						<div class="property line edges" property="edges_lineColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
						<div class="property line edges" property="edges_opacity" type="per_cent_number">\
							<label class="style"> Opacity <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
						<div class="property line edges" property="edges_curve" type="string_selection">\
							<label class="style"> curve <span class="ui-validation-error-message"></span></label>\
							<select  class="curve" type="text">\
								<option value=1>straight</option>\
								<option value=2>bezier</option>\
								<option value=3>bundled</option>\
							</select>\
				       		</div>\
						<div class="property line edges" property="edges_controlPointStepSize" type="number">\
							<label class="style"> Control point step size <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
						<div class="property line edges" property="edges_lineStyle" type="line_shape">\
							<label class="style"> Shape <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
					<h2>Target</h2>\
						<div class="property target edges" property="edges_targetArrowShape" type="edge_shape">\
							<label class="style"> Target Shape <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
						</div>\
						<div class="property target edges" property="edges_targetArrowColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
					<h2>Source</h2>\
						<div class="property source edges" property="edges_sourceArrowShape" type="edge_shape">\
							<label class="style"> Source Shape <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
						</div>\
						<div class="property source edges" property="edges_sourceArrowColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
					<h2>Label</h2>\
						<div class="property label edges" property="edges_labelValign" type="string_selection">\
							<label class="style"> Vertical alignement <span class="ui-validation-error-message"></span></label>\
							<select  class="valign" type="text">\
								<option value=1 >top</option>\
								<option value=2 >center</option>\
								<option value=3 >bottom</option>\
							</select>\
						</div>\
						<div class="property label edges" property="edges_labelHalign" type="string_selection">\
							<label class="style"> Horizontal aligment <span class="ui-validation-error-message"></span></label>\
							<select  class="halign" type="text" ">\
								<option value=1 >right</option>\
								<option value=2 >center</option>\
								<option value=3 >left</option>\
							</select>\
						</div>\
						<div class="property label edges" property="edges_labelColor" type="color">\
							<label class="style"> Color <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" readonly>\
				       		</div>\
						<div class="property label edges" property="edges_labelWeight" type="string_selection">\
							<label class="style"> Weight <span class="ui-validation-error-message"></span></label>\
							<select  class="weight" type="text" ">\
								<option value=1 >normal</option>\
								<option value=2 >bold</option>\
								<option value=3 >bolder</option>\
								<option value=4 >lighter</option>\
							</select>\
						</div>\
						<div class="property label edges" property="edges_labelSize" type="number">\
							<label class="style"> Size <span class="ui-validation-error-message"></span></label>\
							<input  class="default" type="text" ">\
				       		</div>\
					</div>'
			);
			
			//set color properties
		    setColors(this.$el);
		
		    // set edge shape properties
		    setEdgeShape(this.$el);
			//set line shape properties
			setLineShape(this.$el);
		
			//set numbers properties
			setNumber(this.$el);
		
			//set per cent number properties
			setRate(this.$el);
		
			//set string selection
			setString(this.$el);
		},
	
		
	};
	
	
	function inputUpdate($el){
		var	nodes,
			edges = cy.edges(),
			style = cy.style();
		//initialize variable nodes to decide witch nodes can change his style
		if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
					nodes=cy._private.root;			
		}else{
					nodes=cy.nodes();
		}
				
		 $el.find(".property input").each(function(){
		 	
	        var $input = $(this);
		    //// initialize input values////
		     inputColorInit($input, nodes, edges, style);
		     inputShapeInit($input, nodes);
		     inputNumberInit($input, nodes, edges, style);
		     inputRateInit ($input, nodes, edges, style);
   
	      });
	       
	      $el.find(".property select").each(function(){
	       	  
	       	  var $select = $(this);
	       	 //// initialize select values////
	       	 inputStringInit($select, nodes, edges);
	      });
	}
	
	
	//// TODO: remplacer removeShapePicker par une fonction de réutilisation des shapepicker déja affiché 
	function removeShapePicker(shapePicker){
	            if( shapePicker != undefined ){
	                $(".shapepicker").remove();
	                shapepicker = undefined;
	            }
	};

	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Put shape or color picker next to the input																	   ////
	////		Inputs: - html elements defined the pickers ($picker)													   ////
	////				- html input elements associated at the picker 													   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function positionAtInput($picker, $input){
           	 $picker.css({
               		position: "absolute",
			 		top: $input.offset().top + $input.outerHeight(),
                	left: $input.offset().left,
                
            	});
            
            	if( $picker.offset().top + $picker.outerHeight() > $(window).height() ){
                	$picker.css({
                    		top: $input.offset().top - $picker.outerHeight()
                	});
            	}     
	};
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Hide shape or color picker when focus input is lost															   ////
	////		Inputs: - html elements defined the pickers ($picker)													   ////
	////				- html input elements associated to the picker                                                     ////
	////				- defined function 													   	                           ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////   
	function hideWithInput($picker, $input, fn){
        	if ($picker.find(".header").is(":visible")) {
        		// IE set focus to color_picker, forcing a blur on input, so blur cannot be used here.
        		// Let's just create a close button instead:
        		$(".colorpicker .ui-icon-close").on("click", function(e){
        			e.preventDefault();
					fn();
        		});
        		$(".shapepicker .ui-icon-close").on("click", function(e){
        			e.preventDefault();
					fn();
        		});
        	} 
		else {
        		// Regular GOOD browsers!
	        	$input.blur( function(){
						fn();
	        	});
		}
            
        $(window).resize( function(){
                fn();
        });

	};
	
	
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define color input values and define color picker when focusin on color input							   ////
	////		Inputs: - 						 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function inputColorInit ($input, nodes, edges, style){
		
		    //// initialize input values////
		    switch( $input.parent().attr("property") ) {			
	            case "core_backgroundColor":
					$input.val($.Color($("#cy").css('background-color')).toHexString()).css("background-color" ,$input.val());	
	            break;
		   		case "core_selectionBoxColor":	
	        			$input.val(style._private.coreStyle["selection-box-color"].strValue).css("background-color" , $input.val());				
	           	break;
				case "core_selectionBoxBorderColor":	
	        			$input.val(style._private.coreStyle["selection-box-border-color"].strValue).css("background-color", $input.val());
	            break;
	 			case "nodes_borderColor":	
						$input.val(nodes.css("border-color")).css("background-color" ,$input.val());
	            break;
		   		case "nodes_backgroundColor":	
	        			$input.val(nodes.css("background-color")).css("background-color" , $input.val());
	           	break;
				case "nodes_labelColor":
						$input.val(nodes.css("color")).css("background-color" , $input.val());
				break;
				case "edges_lineColor":	
						$input.val(edges.css("line-color")).css("background-color" ,$input.val());
	            break;
		   		case "edges_targetArrowColor":	
	        			$input.val(edges.css("target-arrow-color")).css("background-color" , $input.val());
	           	break;
				case "edges_sourceArrowColor":	
	        			$input.val(edges.css("source-arrow-color")).css("background-color", $input.val());
	           	break;
				case "edges_labelColor":
						$input.val(edges.css("color")).css("background-color" , $input.val());
				break;
	           } 
	}
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize color input values and define color picker when focusin on color input							   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////  
	function setColors ($el) {
				   
		var			nodes,
					edges = cy.edges(),
					style = cy.style();
		
	
		//initialize variable nodes to decide witch nodes can change his style
		if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
					nodes=cy._private.root;			
		}else{
					nodes=cy.nodes();
		}
				
		 $el.find(".property[type=color] input").each(function(){
		 	
	        var $input = $(this);
		    $input.addClass("color_sample_bg");
		    
		    inputColorInit($input, nodes, edges, style);
		       			
		    //// add picker near input when clicked ////
		    $input.focusin( function(){

	                
	            if (!$.layout.browser.msie) { $(".colorpicker .header").hide(); }
	             
	            //initialize variable nodes to decide witch nodes can change his style
				if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
							nodes=cy._private.root;			
				}else{
							nodes=cy.nodes();
				}
	
				  var colorPickerInternals =  $input.colorPicker({
						onShow: function (colpkr) {
								rightPickr= $("#side-resizer").css("right");
								$(colpkr)
									.css("right",rightPickr).css("left", "")
									.slideDown(50);
									
									cy.off("mouseout mouseover touchout touchover");
								return;
							},
						onHide: function (colpkr) {
								cy.elements(":selected").unselect();
								$(colpkr).fadeOut(50);
								switch( $input.parent().attr("property") ) {
					   					case "nodes_backgroundColor":
					   						nodes.css("background-color" , $input.val())
					   						.data("previousCss").backgroundColor = $input.val();				   						
				           				break;
										case "nodes_borderColor":
											nodes.css("border-color", $input.val())
											.data("previousCss").borderColor = $input.val();	
				            			break;
										case "nodes_labelColor":
											nodes.css("color" , $input.val())
											.data("previousCss").labelColor = $input.val();
				           				break;
										case "edges_lineColor":	
											edges.css("line-color", $input.val())
											.data("previousCss").lineColor = $input.val();
				            			break;
					   					case "edges_targetArrowColor":
					   						edges.css("target-arrow-color" , $input.val())
											.data("previousCss").targetArrowColor = $input.val();
				           				break;
										case "edges_sourceArrowColor":
											edges.css("source-arrow-color" , $input.val())
											.data("previousCss").sourceArrowColor = $input.val();
				           				break;
										case "edges_labelColor":
											edges.css("color" , $input.val())
											.data("previousCss").labelColor = $input.val();	
				           				break;
									
									};
									
									//apply style to all nodes without root
									var root = cy._private.root;
									
									if($("#vizstyle_Nodes > form").find("input:checked").val() == "children"){
										var previousCss = root.data("previousCss"); 
										root.css({
														backgroundColor: previousCss.backgroundColor,
														backgroundImage: previousCss.backgroundImage,
														borderColor: previousCss.borderColor,
														color: previousCss.color,
														lineColor: previousCss.lineColor,
														lineStyle: previousCss.lineStyle,
														overlayColor: previousCss.overlayColor,
														targetArrowColor: previousCss.targetArrowColor,
														textOutlineColor: previousCss.textOutlineColor,
											});
									}else{
										root.data("previousCss", root.css());
									};
									
									
									return;
						},
						onSubmit: function() {
								cy.elements(":selected").unselect();
								switch( $input.parent().attr("property") ) {
					   					case "nodes_backgroundColor":
					   						nodes.css("background-color" , $input.val())
											.data("previousCss").backgroundColor = $input.val();
				           				break;
										case "nodes_borderColor":
											nodes.css("border-color", $input.val())
											.data("previousCss").borderColor = $input.val();
				            			break;
										case "nodes_labelColor":
											nodes.css("color" , $input.val())
											.data("previousCss").labelColor = $input.val();
				           				break;
										case "edges_lineColor":	
											edges.css("line-color", $input.val())
											.data("previousCss").lineColor = $input.val();
				            			break;
					   					case "edges_targetArrowColor":
					   						edges.css("target-arrow-color" , $input.val())
											.data("previousCss").targetArrowColor = $input.val();	
				           				break;
										case "edges_sourceArrowColor":
											edges.css("source-arrow-color" , $input.val())
											.data("previousCss").sourceArrowColor = $input.val();
				           				break;
										case "edges_labelColor":
											edges.css("color" , $input.val())
											.data("previousCss").labelColor = $input.val();
				           				break;
				           				
				           				//apply style to all nodes without root 
				           				var root = cy._private.root;
										if($("#vizstyle_Nodes > form").find("input:checked").val() == "children"){
											
											var previousCss = root.data("previousCss");
											
											root.css({
															backgroundColor: previousCss.backgroundColor,
															backgroundImage: previousCss.backgroundImage,
															borderColor: previousCss.borderColor,
															color: previousCss.color,
															lineColor: previousCss.lineColor,
															lineStyle: previousCss.lineStyle,
															overlayColor: previousCss.overlayColor,
															targetArrowColor: previousCss.targetArrowColor,
															textOutlineColor: previousCss.textOutlineColor,
												});
										}else{
											root.data("previousCss", root.css());
										};
									
								};
						},
						onChange: function (){
								var colorSelected = "#" + $(this).find(".colorpicker_hex input").val();
									
								switch( $input.parent().attr("property") ) {
			                		case "core_backgroundColor":
			                			$("#cy").css("background-color", colorSelected);
			                			$input.val(colorSelected).css("background-color" ,colorSelected);		
			            			break;
				   					case "core_selectionBoxColor":	
			        					style.selector("core").css("selection-box-color" , colorSelected);
			        					$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									case "core_selectionBoxBorderColor":	
			        					style.selector("core").css("selection-box-border-color" , colorSelected);
			        					$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
				   					case "nodes_backgroundColor":	
			        					//f_nodes.css("background-color" , $input.val());
			        					$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									case "nodes_borderColor":	
										//f_nodes.css("border-color", $input.val());
										$input.val(colorSelected).css("background-color" ,colorSelected);
			            			break;
									case "nodes_labelColor":
										//f_nodes.css("color" , $input.val());
										$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									case "edges_lineColor":	
										//f_edges.css("line-color", $input.val());
										$input.val(colorSelected).css("background-color" ,colorSelected);
			            			break;
				   					case "edges_targetArrowColor":	
			        					//f_edges.css("target-arrow-color" , $input.val());
			        					$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									case "edges_sourceArrowColor":	
			        					//f_edges.css("source-arrow-color" , $input.val());
			        					$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									case "edges_labelColor":
										//f_edges.css("color" , $input.val());
										$input.val(colorSelected).css("background-color" ,colorSelected);
			           				break;
									
								};
								  
			           			} 
					
	               	});
	
				if(colorPickerInternals != undefined ){
	                    		colorPickerInternals.colorPickerSetColor( $input.val());
	             }
				//// include in cytoscape.picker.js ////
	                /*positionAtInput($("#color_picker"), $input);
	                
	                	hideWithInput($("#color_picker"), $input, function(){
	                    		remove_color_picker();
	                	});*/
	            });          	
	
		});
	};
	

	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define nodes shape input values and define shape picker when focusin on nodes shape input				   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function inputShapeInit($input, nodes){
		 if($input.parent().attr("property")=="nodes_shape"){ 
		  $input
	        	//// initialize input values////
	           	.val(nodes.css("shape"));
	    }
	}
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize nodes shape input values and define shape picker when focusin on nodes shape input				   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
	function setNodeShape ($el) {

		var nodes,
			types = ["square", "roundrectangle", "ellipse", "triangle"];

			//initialize variable nodes to decide witch nodes can change his style
			if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
						nodes=cy._private.root;			
			}else{
						nodes=cy.nodes();
			}
		
		$el.find(".property[type=node_shape] input").each(function(){
			
	    	var $input = $(this);	
	       inputShapeInit($input, nodes);
	        $input
	        	.addClass("shape_sample_bg")
	           	.css("shape", $input.val())
	            //// add picker near input when clicked ////
	         	.on("focusin", function(){
	         		//initialize variable nodes to decide witch nodes can change his style
					if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
								nodes=cy._private.root;			
					}else{
								nodes=cy.nodes();
					}
	            
	                var shapePicker = $('<div id="node_shapepicker" class="shapepicker"></div>');
	                $("body").append(shapePicker);
	                
	               
	                for(var i = 0; i < types.length; i++){
	                    var type = types[i];
	                
	                    shapePicker.append('<div class="shape ' + type + '" shape="' + type + '"></div>');
	                }

	                shapePicker.children().on("mousedown", function(){
	                    					var type = $(this).attr("shape");
	                   	 					$input.val(type);    
	                });
			                
	                positionAtInput(shapePicker, $input);
	                
	                hideWithInput(shapePicker, $input, function(){
	                   removeShapePicker(shapePicker);
	                 	nodes
	                    	.css("shape" , $input.val())
							.data("previousCss").shape = $input.val();

						if($("#vizstyle_Nodes > form").find("input:checked").val() == "children"){
							var root=cy._private.root;					
							var previousCss = root.data("previousCss");
								root.css("shape", previousCss.shape);
						}
						
						// force current shape when root is selected
						var rootId = nodes.data("id");
						cy.style().selector('#'+rootId+':selected').css("shape", $input.val());
															
	                	});
	                  
				})
				
				

	        .keypress(function(e) {
			    if(e.which == 13) {
			       $input.trigger("focusout");
		    	}
		    });
	        
			
	  	});
	};
	
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define line shape input values and define shape picker when focusin on line shape input					   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
	function inputLineShapeInit($input, edges) {
		if( $input.parent().attr("property") == "edges_lineStyle") {
	        		$input.val(edges.css("line-style")).css("line-style" , $input.val());
	      }
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize line shape input values and define shape picker when focusin on line shape input					   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////// 
	function setLineShape($el) {
		var edges= cy.edges(),
	        style = cy.style();
	        
		 $el.find(".property[type=line_shape] input").each(function(){
	          	var $input = $(this);
	     		 //// initialize input values////     	
				inputLineShapeInit($input, edges);
	           
		       //// add picker near input when clicked ////
		       $input
		       		.on("focusin", function(){ 
		            
		                var shapePicker = $('<div id="line_shapepicker" class="shapepicker floating_widget"></div>');
		                $("body").append(shapePicker);
		                
		                var types = ["dotted", "dashed", "solid"];
		                for(var i = 0; i < types.length; i++){
		                    var type = types[i];
		                
		                    shapePicker.append('<div class="shape ' + type + '" shape="' + type + '"></div>');
		                }
		
		                shapePicker.children().on("mousedown", function(){
		                    			var type = $(this).attr("shape"); 
		                   		 		$input.val(type);   
		                });
		                
		                positionAtInput(shapePicker, $input);             
		                
		                hideWithInput(shapePicker, $input, function(){
		                    removeShapePicker(shapePicker);
		                   if( $input.parent().attr("property") == "edges_lineStyle" ) {	
				        		edges
				        				.css("line-style" , $input.val())
										.data("previousCss").lineStyle = $input.val();
			        		}	
		                    
		                });
			         })
				   .keypress(function(e) {
					    if(e.which == 13) {
					       $input.trigger("focusout");
				    	}
				   });
	  	});
	};
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define edges shape input (target shape, source shape) values and define shape picker 					       ////
	//// 	when focusin on edge shape input					  														   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function  inputEdgeShapeInit ($input, edges){
		switch( $input.parent().attr("property") ) {
		   		case "edges_targetArrowShape":	
	        			$input.val(edges.css("target-arrow-shape")).css("target-arrow-shape" , $input.val());
	           	break;
				case "edges_sourceArrowShape":	
	        			$input.val(edges.css("source-arrow-shape")).css("source-arrow-shape", $input.val());
	           	break;
	       };
	
	}
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize edges shape input (target shape, source shape) values and define shape picker 					   ////
	//// 	when focusin on edge shape input					  														   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function  setEdgeShape ($el){
		   var edges = cy.edges(),
	           style = cy.style(),
	           types = ["diamond", "triangle", "square", "circle", "tee", "none"];
	           	
		   $el.find(".property[type=edge_shape] input").each(function(){
	       
	       var $input = $(this);
	       //// initialize input values////   
		   inputEdgeShapeInit($input, edges);
	           
	       //// add picker near input when clicked ////
	       $input
	       		.addClass("shape_sample_bg")
	            //// add picker near input when clicked ////
	         	.on("focusin", function(){ 
	            	
	                var shapePicker = $('<div id="edge_shapepicker" class="shapepicker floating_widget"></div>');
	                $("body").append(shapePicker);
	                
	                for(var i = 0; i < types.length; i++){
	                    var type = types[i];
	                
	                    shapePicker.append('<div class="shape ' + type + '" shape="' + type + '"></div>');
	                }
	
	                shapePicker.children().on("mousedown", function(){
	                    	var type = $(this).attr("shape"); 
	                    	$input.val(type);
	                    
	                });
	           
	                
	                positionAtInput(shapePicker, $input);             
	                
	                hideWithInput(shapePicker, $input, function(){
	                    removeShapePicker(shapePicker);
	                    switch( $input.parent().attr("property") ) {
		   				case "edges_targetArrowShape":	
	        					edges.css("target-arrow-shape" , $input.val())
								.data("previousCss").targetArrowShape = $input.val();
	           			break;
						case "edges_sourceArrowShape":	
	        					edges.css("source-arrow-shape" , $input.val())
								.data("previousCss").sourceArrowShape = $input.val();
	           			break;
	              	}
	                });
	            })
		   .keypress(function(e) {
		    if(e.which == 13) {
		       $input.trigger("focusout");
	    	}
	  });
	
	  });
	
	};

	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define number input values and define action after foscusout				   							   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function inputNumberInit ($input, nodes, edges, style){ 
		 switch( $input.parent().attr("property") ) {
				case "core_selectionBoxBorderWidth":	
					$input.val(style._private.coreStyle["selection-box-border-width"].value);
	            break;
	            case "nodes_borderWidth":	
					$input.val(nodes.css("border-width"));
	            break;
				case "nodes_width":	
					$input.val(nodes.css("width"));
	            break;	
				case "nodes_height":	
					$input.val(nodes.css("height"));
	            break;
				case "nodes_labelSize":	
					$input.val(nodes.css("font-size"));
	            break;
				case "edges_width":	
					$input.val(edges.css("width"));
	            break;	
				case "edges_controlPointStepSize":	
					$input.val(edges.css("control-point-step-size"));
	            break;
	           case "edges_labelSize":	
					$input.val(edges.css("font-size"));
	            break;
	           }; 
	}
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize number input values and define action after foscusout				   							   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function setNumber ($el){ 
		var nodes,
	        edges = cy.edges(),
			style = cy.style();
		
			//initialize variable nodes to decide witch nodes can change his style
			if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
						nodes=cy._private.root;			
			}else{
						nodes=cy.nodes();
			}
		
			
		$el.find(".property[type = number] input").each(function(){
	         var $input = $(this);
	            
			 //// initialize input values////   
		    inputNumberInit($input, nodes, edges, style);
	
			  //// set input values ////
		     $input
		     	.on("focusout", function(){
		     		
		     		//initialize variable nodes to decide witch nodes can change his style
					if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
								nodes=cy._private.root;			
					}else{
								nodes=cy.nodes();
					}
					
				  switch( $input.parent().attr("property") ) {
					case "core_selectionBoxBorderWidth":	
						style.selector("core").css("selection-box-border-width" , $input.val());
	            	break;
					case "nodes_borderWidth":	
						nodes.css("border-width" , $input.val())
						.data("previousCss").borderWidth = $input.val();
	            	break;
	                case "nodes_width":
	                	nodes.css("width" , $input.val())
						.data("previousCss").width = $input.val();
	            	break;
					case "nodes_height":	
						nodes.css("height" , $input.val())
						.data("previousCss").height = $input.val();
	            	break;
					case "nodes_labelSize":	
						nodes.css("font-size" , $input.val())
						.data("previousCss").fontSize = $input.val();
	            	break;
					case "edges_width":	
						edges.css("width" , $input.val())
						.data("previousCss").width = $input.val();
	            	break;
					case "edges_controlPointStepSize":	
						edges.css("control-point-step-size" , $input.val())
						.data("previousCss").controlPointStepSize = $input.val();
						//fix no update view
						nodes.each(function(){
							var positionX = this.position("x");
							this.position("x", positionX+1);
							this.position("x", positionX-1);
						});
	            	break;
	            	case "edges_labelSize":	
						edges.css("font-size" , $input.val())
						.data("previousCss").fontSize = $input.val();
	            	break;
				 };
				 
				 //apply style to all nodes without root 					
				var root = cy._private.root;
				if ($("#vizstyle_Nodes > form").find("input:checked").val() == "children") {
					
					var previousCss = root.data("previousCss");
					
					root.css({
							borderWidth: previousCss.borderWidth,
							fontSize: previousCss.fontSize,
							height: previousCss.height,
							textOutlineWidth: previousCss.textOutlineWidth,
							width: previousCss.width,	
					});
					
				}else{
						root.data("previousCss", root.css());
				};

		     })
		  	.keypress(function(e) {
			    if(e.which == 13) {
			       $input.trigger("focusout");
		    	}
		   });
		});

	};


	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Define rate input values and define action after foscusout												   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function inputRateInit ($input, nodes, edges, style){
			
		switch( $input.parent().attr("property") ) {
			case "core_selectionBoxOpacity":
				$input.val(style._private.coreStyle["selection-box-opacity"].value);
			break;
			case "nodes_borderOpacity":
				$input.val(nodes.css("border-opacity"));
			break;
			case "nodes_backgroundOpacity":
				$input.val(nodes.css("background-opacity"));
			break;
			case "edges_opacity":
				$input.val(edges.css("opacity"));
			break;
		};

	}
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////														                                                           ////
	////	Initialize rate input values and define action after foscusout												   ////
	////		Inputs: - html elements defined 																		   ////
	////																												   ////
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	function setRate ($el){
		var nodes,
	        edges = cy.edges(),
			style = cy.style();
			
		//initialize variable nodes to decide witch nodes can change his style
		if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
					nodes=cy._private.root;			
		}else{
					nodes=cy.nodes();
		}
 	
		$el.find(".property[type =per_cent_number] input").each(function(){
	            var $input = $(this);
 			//// initialize input values//// 
		    inputRateInit ($input, nodes, edges, style);
	        
			//// set input values ////
		  	$input.on("focusout", function(){
		  		
					//initialize variable nodes to decide witch nodes can change his style
					if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
								nodes=cy._private.root;			
					}else{
								nodes=cy.nodes();
					}	
						
				  switch( $input.parent().attr("property") ) {
					case "core_selectionBoxOpacity":	
						style.selector("core").css("selection-box-opacity" , $input.val());
	            	break;
	                case "nodes_borderOpacity":	
						nodes.css("border-opacity" , $input.val())
						.data("previousCss").borderOpacity = $input.val();
	            	break;
					case "nodes_backgroundOpacity":	
						nodes.css("background-opacity" , $input.val())
						.data("previousCss").backgroundOpacity = $input.val();	
	            	break;
					case "edges_opacity":	
						edges.css("opacity" , $input.val())
						.data("previousCss").opacity = $input.val();	
	            	break;
				 };
				
				//apply style to all nodes without root 					
				var root = cy._private.root;
				if ($("#vizstyle_Nodes > form").find("input:checked").val() == "children") {
					
					var previousCss = root.data("previousCss");
					
					root.css({
							backgroundOpacity: previousCss.backgroundOpacity,	
							borderOpacity: previousCss.borderOpacity,
							opacity: previousCss.opacity,
							overlayOpacity: previousCss.overlayOpacity,
							textOutlineOpacity: previousCss.textOutlineOpacity,	
					});
					
				}else{
						root.data("previousCss", root.css());
				};
			 
		  	})
		 	.keypress(function(e) {
			    if(e.which == 13) {
			       $input.trigger("focusout");
		    	}
		  });
		});
	};

	
	function inputStringInit($select, nodes, edges){
		 switch( $select.parent().attr("property")) {
	             case "nodes_labelValign":
					var index = 1;
					$("select[class = valign] > option").each(function (){
						if ( $("select[class = valign] option:selected").html() != nodes.css("text-valign")){
	
							$("select[class = valign] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = valign] option[value="+index+"]").attr("selected","selected");
						}
							
					});
	            break;
				case "nodes_labelHalign":
					var index = 1;
					$("select[class = halign] > option").each(function (){
						if ( $("select[class = halign] option:selected").html() != nodes.css("text-halign")){
	
							$("select[class = halign] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = halign] option[value="+index+"]").attr("selected","selected");
						}
		
					});
	            break;
				case "nodes_labelWeight":
					var index = 1;
					$("select[class = weight] > option").each(function (){
						if ( $("select[class = weight] option:selected").html() != nodes.css("font-weight")){
	
							$("select[class = weight] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = weight] option[value="+index+"]").attr("selected","selected");
						}
					});
	            break;
				case "edges_curve":
					var index = 1;
					$("select[class = curve] > option").each(function (){
						
						if ( $("select[class = curve] option:selected").html() != edges.css("curve-style")){
	
							$("select[class = curve] option[selected='selected']").removeAttr("selected"); 
							index ++;
							$("select[class = curve] option[value="+index+"]").attr("selected","selected");
						}
					
						//disable control point step if edges style is straight
						if($("select[class = curve] option:selected").html() == "straight"){
							$select.parent().siblings().filter("[ property = edges_controlPointStepSize]").find("input").prop('disabled', true);
						}
							
					});
	            break;
	            case "edges_labelValign":
					var index = 1;
					$("select[class = valign] > option").each(function (){
						if ( $("select[class = valign] option:selected").html() != edges.css("text-valign")){
	
							$("select[class = valign] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = valign] option[value="+index+"]").attr("selected","selected");
						}
							
					});
	            break;
				case "edges_labelHalign":
					var index = 1;
					$("select[class = halign] > option").each(function (){
						if ( $("select[class = halign] option:selected").html() != edges.css("text-halign")){
	
							$("select[class = halign] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = halign] option[value="+index+"]").attr("selected","selected");
						}
		
					});
	            break;
				case "edges_labelWeight":
					var index = 1;
					$("select[class = weight] > option").each(function (){
						if ( $("select[class = weight] option:selected").html() != edges.css("font-weight")){
	
							$("select[class = weight] option[selected='selected']").removeAttr("selected"); 
							index ++;
	 						$("select[class = weight] option[value="+index+"]").attr("selected","selected");
						}
					});
	            break;
	        };
	}
	
	function setString ($el){
		var nodes,
	        edges = cy.edges(); 
	        
		//initialize variable nodes to decide witch nodes can change his style
		if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
					nodes=cy._private.root;			
		}else{
					nodes=cy.nodes();
		}
		
		$el.find(".property[type = string_selection] select").each(function(){
			var $select = $(this);
			//// initialize input values//// 			
		   inputStringInit($select, nodes, edges);
	           	
			//// set input values ////
		  	$select.click( function(){
		  		
		  			//initialize variable nodes to decide witch nodes can change his style
					if($("#vizstyle_Nodes > form").find("input:checked").val() == "root"){
								nodes=cy._private.root;			
					}else{
								nodes=cy.nodes();
					}
		  		
		  		 
				  switch( $select.parent().attr("property") ) {
	                case "nodes_labelValign":					
						if ( $("select[class = valign] option:selected").html() != nodes.css("text-valign")){
							$("select[class = valign] option[selected='selected']").removeAttr("selected");
							$("select[class = valign] > option:selected").attr("selected","selected");
						};					
						nodes.css("text-valign" , $("select[class = valign] > option:selected").text())
						.data("previousCss").textValign = $("select[class = valign] > option:selected").text();
	            	break;
					case "nodes_labelHalign":
					    if ( $("select[class = halign] option:selected").html() != nodes.css("text-halign")){
							$("select[class = halign] option[selected='selected']").removeAttr("selected");
							$("select[class = halign] > option:selected").attr("selected","selected");
						};
						nodes.css("text-halign" ,$("select[class = halign] > option:selected").text())
						.data("previousCss").textHalign = $("select[class = halign] > option:selected").text();
						
	            	break;
					case "nodes_labelWeight":
						if ( $("select[class = weight] option:selected").html() != nodes.css("font-weight")){
							$("select[class = weight] option[selected='selected']").removeAttr("selected");
							$("select[class = weight] > option:selected").prop("selected","selected");
						};
						nodes.css("font-weight" , $("select[class = weight] > option:selected").text())
						.data("previousCss").fontWeight = $("select[class = weight] > option:selected").text();
						
	            	break;
					case "edges_curve":
						if ( $("select[class = curve] > option:selected").html() != edges.css("curve-style")){
							$("select[class = curve] option[selected='selected']").removeAttr("selected");
							$("select[class = curve] > option:selected").prop("selected","selected");	
						};
						
						//implement fake straight edges style
						if($("select[class = curve] > option:selected").html() == "straight"){
							edges.css({
								curveStyle: "bezier",
								controlPointStepSize : 1	
							});
							edges.data("previousCss").curveStyle = "bezier";
							edges.data("previousCss").controlPointStepSize = 1;
							$select.parent().siblings().filter("[ property = edges_controlPointStepSize]").find("input").prop('disabled', true);
							
							
						}else{
							edges.css({
								curveStyle: $("select[class = curve] > option:selected").html(),
								controlPointStepSize : 	40
							});
							edges.data("previousCss").curveStyle = "bezier";
							edges.data("previousCss").controlPointStepSize = 	40;
							$select.parent().siblings().filter("[ property = edges_controlPointStepSize]").find("input").val("40px").prop('disabled', false);

						}
						//fix no update view
						nodes.each(function(){
								var positionX = this.position("x");
								this.position("x", positionX+1);
								this.position("x", positionX-1);
						});
						
	            	break;
	                case "edges_labelValign":				
						if ( $("select[class = valign] option:selected").html() != edges.css("text-valign")){
							$("select[class = valign] option[selected='selected']").removeAttr("selected");
							$("select[class = valign] > option:selected").attr("selected","selected");
						};
						edges.css("text-valign" , $("select[class = valign] > option:selected").text())
						.data("previousCss").textValign = $("select[class = valign] > option:selected").text();
	            	break;
					case "edges_labelHalign":
					        if ( $("select[class = halign] option:selected").html() != edges.css("text-halign")){
							$("select[class = halign] option[selected='selected']").removeAttr("selected");
							$("select[class = halign] > option:selected").attr("selected","selected");
						};
						edges.css("text-halign" ,$("select[class = halign] > option:selected").text())
						.data("previousCss").textHalign = $("select[class = halign] > option:selected").text();	
	            	break;
					case "edges_labelWeight":	
						if ( $("select[class = weight] option:selected").html() != edges.css("font-weight")){
							$("select[class = weight] option[selected='selected']").removeAttr("selected");
							$("select[class = weight] > option:selected").attr("selected","selected");
						};
						edges.css("font-weight" , $("select[class = weight] > option:selected").text())
						.data("previousCss").fontWeight = $("select[class = weight] > option:selected").text();
	               break;
				 };
				 
				 //apply style to all nodes without root 					
				var root = cy._private.root;
				if ($("#vizstyle_Nodes > form").find("input:checked").val() == "children") {
					
					var previousCss = root.data("previousCss");
					
					root.css({							
							fontWeight: previousCss.fontWeight,
							textHalign: previousCss.textHalign,
							textValign: previousCss.textValign,	
					});
					
				}else{
						root.data("previousCss", root.css());
				};
		  	});
		 
		});
	};

	var methods={
		init : function(startStyle){
			var $el= $(this);	
			var vizStyle = new VizStyle($el);
			$el.data("VizStyle", vizStyle);
			switch(startStyle) {
                case "core":
					vizStyle.coreHtml($el);
				break;
				case "node":
					vizStyle.nodesHtml($el);
				break;
				case "edge":
					vizStyle.edgesHtml($el);
				break;
			};
		return vizStyle;
		}
	};
	
	$.fn.extend({
			vizStyle: methods.init
	});

})(jQuery);